===============
django-envelope
===============

``django-envelope`` is a simple contact form app for Django web framework.

See the docs at http://django-envelope.rtfd.org.

CI server is at https://jenkins.shiningpanda.com/django-envelope/.
